==> jc-1.4.0.tar.gz: soot/util/StringTools.h <==
// public class soot.util.StringTools

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8e89953898085705 soot_util_StringTools

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_StringTools_H_
#define _JC_soot_util_StringTools_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_util_StringTools$sub_refs	_jc_soot_util_StringTools$sub_refs;
typedef struct _jc_soot_util_StringTools$sub_nonrefs	_jc_soot_util_StringTools$sub_nonrefs;
typedef struct _jc_soot_util_StringTools$refs	_jc_soot_util_StringTools$refs;
typedef struct _jc_soot_util_StringTools$nonrefs	_jc_soot_util_StringTools$nonrefs;
typedef struct _jc_soot_util_StringTools$object	_jc_soot_util_StringTools$object;

typedef struct _jc_soot_util_StringTools$fields_struct	_jc_soot_util_StringTools$fields_struct;
typedef const struct _jc_soot_util_StringTools$vmethods	_jc_soot_util_StringTools$vmethods;
typedef const struct _jc_soot_util_StringTools$vtable	_jc_soot_util_StringTools$vtable;
typedef const struct _jc_soot_util_StringTools$vtype	_jc_soot_util_StringTools$vtype;

// Class fields structure
struct _jc_soot_util_StringTools$fields_struct {
	struct _jc_java_lang_String$object	*lineSeparator;
};
extern _jc_soot_util_StringTools$fields_struct _jc_soot_util_StringTools$class_fields;

// Constructors
extern void _jc_soot_util_StringTools$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_StringTools$object *);

// Static methods
extern void _jc_soot_util_StringTools$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern jchar _jc_soot_util_StringTools$method$getCFormatChar$b6346fd39e944fe3(_jc_env *, jchar);
extern struct _jc_java_lang_String$object *_jc_soot_util_StringTools$method$getEscapedStringOf$d4093770200b4055(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_soot_util_StringTools$method$getQuotedStringOf$831b19c537e0dc75(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_soot_util_StringTools$method$getUnEscapedStringOf$5d61f69969ff746b(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_soot_util_StringTools$method$getUnicodeStringFromChar$03b50b4f02c07298(_jc_env *, jchar);
extern struct _jc_java_lang_String$object *_jc_soot_util_StringTools$method$replaceAll$1d078442fa37992f(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_soot_util_StringTools$vmethods {
};

// Vtable
struct _jc_soot_util_StringTools$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_StringTools$vmethods	soot_util_StringTools;
};

// Vtype
struct _jc_soot_util_StringTools$vtype {
	_jc_type			type;
	_jc_soot_util_StringTools$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_StringTools$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_StringTools$refs {
    _jc_soot_util_StringTools$sub_refs	soot_util_StringTools;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_StringTools$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_StringTools$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_StringTools$sub_nonrefs	soot_util_StringTools;
};

// Object instance structure
struct _jc_soot_util_StringTools$object {
	_jc_soot_util_StringTools$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_StringTools$vtype	*vtype;
	_jc_soot_util_StringTools$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_StringTools$vtype _jc_soot_util_StringTools$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_StringTools, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_StringTools$class_object;

#endif	/* _JC_soot_util_StringTools_H_ */

==> jc-1.4.6.tar.gz: soot/util/StringTools.h <==
// public class soot.util.StringTools

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8e89953898085705 soot_util_StringTools

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_StringTools_H_
#define _JC_soot_util_StringTools_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_util_StringTools$sub_refs	_jc_soot_util_StringTools$sub_refs;
typedef struct _jc_soot_util_StringTools$sub_nonrefs	_jc_soot_util_StringTools$sub_nonrefs;
typedef struct _jc_soot_util_StringTools$refs	_jc_soot_util_StringTools$refs;
typedef struct _jc_soot_util_StringTools$nonrefs	_jc_soot_util_StringTools$nonrefs;
typedef struct _jc_soot_util_StringTools$object	_jc_soot_util_StringTools$object;

typedef struct _jc_soot_util_StringTools$fields_struct	_jc_soot_util_StringTools$fields_struct;
typedef const struct _jc_soot_util_StringTools$vmethods	_jc_soot_util_StringTools$vmethods;
typedef const struct _jc_soot_util_StringTools$vtable	_jc_soot_util_StringTools$vtable;
typedef const struct _jc_soot_util_StringTools$vtype	_jc_soot_util_StringTools$vtype;

// Class fields structure
struct _jc_soot_util_StringTools$fields_struct {
	struct _jc_java_lang_String$object	*lineSeparator;
};
extern _jc_soot_util_StringTools$fields_struct _jc_soot_util_StringTools$class_fields;

// Constructors
extern void _jc_soot_util_StringTools$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_StringTools$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_soot_util_StringTools$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern jchar _jc_soot_util_StringTools$method$getCFormatChar$b6346fd39e944fe3(_jc_env *, jchar) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_util_StringTools$method$getEscapedStringOf$d4093770200b4055(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_util_StringTools$method$getQuotedStringOf$831b19c537e0dc75(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_util_StringTools$method$getUnEscapedStringOf$5d61f69969ff746b(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_util_StringTools$method$getUnicodeStringFromChar$03b50b4f02c07298(_jc_env *, jchar) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_util_StringTools$method$replaceAll$1d078442fa37992f(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_util_StringTools$vmethods {
};

// Vtable
struct _jc_soot_util_StringTools$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_StringTools$vmethods	soot_util_StringTools;
};

// Vtype
struct _jc_soot_util_StringTools$vtype {
	_jc_type			type;
	_jc_soot_util_StringTools$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_StringTools$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_StringTools$refs {
    _jc_soot_util_StringTools$sub_refs	soot_util_StringTools;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_StringTools$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_StringTools$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_StringTools$sub_nonrefs	soot_util_StringTools;
};

// Object instance structure
struct _jc_soot_util_StringTools$object {
	_jc_soot_util_StringTools$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_StringTools$vtype	*vtype;
	_jc_soot_util_StringTools$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_StringTools$vtype _jc_soot_util_StringTools$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_StringTools, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_StringTools$class_object;

#endif	/* _JC_soot_util_StringTools_H_ */
